package de.intevation.mxd.reader;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.ILineSymbol;
import com.esri.arcgis.display.SimpleLineSymbol;
import com.esri.arcgis.display.esriSimpleLineStyle;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;

/**
 * Reads simple line symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class SimpleLineSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(SimpleLineSymbolReader.class);

    /**
     * Private member.
     */
    private SimpleLineSymbol symbol;

    public SimpleLineSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof SimpleLineSymbol) {
            this.symbol = (SimpleLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a SimpleLineSymbol!");
        }
    }

    public SimpleLineSymbolReader(ILineSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof SimpleLineSymbol) {
            this.symbol = (SimpleLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a SimpleLineSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        logger.debug("read()");
        Element symbolElement = util.addSymbol(parent);

        symbolElement.setAttribute("name", symbol.getNameString());
        symbolElement.setAttribute("style", "line");
        symbolElement.setAttribute("type", "simple");
        if(symbol.getColor() instanceof IRgbColor) {
            IRgbColor color = (IRgbColor)symbol.getColor();
            Color c = new Color (
                color.getRed(),
                color.getGreen(),
                color.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
        }
        else {
            RgbColor col = new RgbColor();
            col.setRGB(symbol.getColor().getRGB());
            Color c = new Color (
                col.getRed(),
                col.getGreen(),
                col.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
        }

        symbolElement.setAttribute("width", String.valueOf(symbol.getWidth()));

        int style = symbol.getStyle();
        switch(style) {
            case esriSimpleLineStyle.esriSLSSolid:
                    symbolElement.setAttribute("linestyle", "solid"); break;
            case esriSimpleLineStyle.esriSLSDash:
                    symbolElement.setAttribute("linestyle", "dash"); break;
            case esriSimpleLineStyle.esriSLSDot:
                    symbolElement.setAttribute("linestyle", "dot"); break;
            case esriSimpleLineStyle.esriSLSDashDot:
                    symbolElement.setAttribute("linestyle", "dashdot"); break;
            case esriSimpleLineStyle.esriSLSDashDotDot:
                    symbolElement.setAttribute("linestyle", "dashdotdot"); break;
            default: symbolElement.setAttribute ("linestyle", "none");
        }
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
